==> android-aihelp-aar-3.1.7-sources.jar: net/aihelp/data/model/config/StyleSheetEntity.java <==
package net.aihelp.data.model.config;

public class StyleSheetEntity {

    private GeneralEntity general;
    private HelpEntity help;
    private OnLineEntity onLine;

    public GeneralEntity getGeneral() {
        return general;
    }

    public void setGeneral(GeneralEntity general) {
        this.general = general;
    }

    public HelpEntity getHelp() {
        return help;
    }

    public void setHelp(HelpEntity help) {
        this.help = help;
    }

    public OnLineEntity getOnLine() {
        return onLine;
    }

    public void setOnLine(OnLineEntity onLine) {
        this.onLine = onLine;
    }

    public static class GeneralEntity {
        private NavBarEntity navBar;
        private String horizontal;
        private String vertical;
        private String horizontalImgUrl;
        private String verticalImgUrl;
        private FrontColorEntity frontColor;
        private String textColor;
        private String highlightColor;
        private String buttonColor;
        private String backButton;

        public NavBarEntity getNavBar() {
            return navBar;
        }

        public void setNavBar(NavBarEntity navBar) {
            this.navBar = navBar;
        }

        public String getHorizontal() {
            return horizontal;
        }

        public void setHorizontal(String horizontal) {
            this.horizontal = horizontal;
        }

        public String getVertical() {
            return vertical;
        }

        public void setVertical(String vertical) {
            this.vertical = vertical;
        }

        public String getHorizontalImgUrl() {
            return horizontalImgUrl;
        }

        public void setHorizontalImgUrl(String horizontalImgUrl) {
            this.horizontalImgUrl = horizontalImgUrl;
        }

        public String getVerticalImgUrl() {
            return verticalImgUrl;
        }

        public void setVerticalImgUrl(String verticalImgUrl) {
            this.verticalImgUrl = verticalImgUrl;
        }

        public FrontColorEntity getFrontColor() {
            return frontColor;
        }

        public void setFrontColor(FrontColorEntity frontColor) {
            this.frontColor = frontColor;
        }

        public String getTextColor() {
            return textColor;
        }

        public void setTextColor(String textColor) {
            this.textColor = textColor;
        }

        public String getHighlightColor() {
            return highlightColor;
        }

        public void setHighlightColor(String highlightColor) {
            this.highlightColor = highlightColor;
        }

        public String getButtonColor() {
            return buttonColor;
        }

        public void setButtonColor(String buttonColor) {
            this.buttonColor = buttonColor;
        }

        public String getBackButton() {
            return backButton;
        }

        public void setBackButton(String backButton) {
            this.backButton = backButton;
        }

        public static class NavBarEntity {
            private String color;
            private double transparency;

            public String getColor() {
                return color;
            }

            public void setColor(String color) {
                this.color = color;
            }

            public double getTransparency() {
                return transparency;
            }

            public void setTransparency(double transparency) {
                this.transparency = transparency;
            }
        }

        public static class FrontColorEntity {
            private String color;
            private double transparency;

            public String getColor() {
                return color;
            }

            public void setColor(String color) {
                this.color = color;
            }

            public double getTransparency() {
                return transparency;
            }

            public void setTransparency(double transparency) {
                this.transparency = transparency;
            }
        }
    }

    public static class HelpEntity {
        private String navBar;
        private String noticeBar;
        private String faqList;
        private String faqSectionList;

        public String getNavBar() {
            return navBar;
        }

        public void setNavBar(String navBar) {
            this.navBar = navBar;
        }

        public String getNoticeBar() {
            return noticeBar;
        }

        public void setNoticeBar(String noticeBar) {
            this.noticeBar = noticeBar;
        }

        public String getFaqList() {
            return faqList;
        }

        public void setFaqList(String faqList) {
            this.faqList = faqList;
        }

        public String getFaqSectionList() {
            return faqSectionList;
        }

        public void setFaqSectionList(String faqSectionList) {
            this.faqSectionList = faqSectionList;
        }
    }

    public static class OnLineEntity {
        private String navBar;
        private String robotImgUrl;
        private String customerImgUrl;
        private String userImgUrl;
        private String bgColor;
        private String foreColor;

        public String getNavBar() {
            return navBar;
        }

        public void setNavBar(String navBar) {
            this.navBar = navBar;
        }

        public String getRobotImgUrl() {
            return robotImgUrl;
        }

        public void setRobotImgUrl(String robotImgUrl) {
            this.robotImgUrl = robotImgUrl;
        }

        public String getCustomerImgUrl() {
            return customerImgUrl;
        }

        public void setCustomerImgUrl(String customerImgUrl) {
            this.customerImgUrl = customerImgUrl;
        }

        public String getUserImgUrl() {
            return userImgUrl;
        }

        public void setUserImgUrl(String userImgUrl) {
            this.userImgUrl = userImgUrl;
        }

        public String getBgColor() {
            return bgColor;
        }

        public void setBgColor(String bgColor) {
            this.bgColor = bgColor;
        }

        public String getForeColor() {
            return foreColor;
        }

        public void setForeColor(String foreColor) {
            this.foreColor = foreColor;
        }
    }
}

==> android-aihelp-aar-4.6.0-sources.jar: net/aihelp/data/model/config/StyleSheetEntity.java <==
package net.aihelp.data.model.config;

public class StyleSheetEntity {

    private GeneralEntity general;
    private HelpEntity help;
    private OnLineEntity onLine;

    public GeneralEntity getGeneral() {
        return general;
    }

    public void setGeneral(GeneralEntity general) {
        this.general = general;
    }

    public HelpEntity getHelp() {
        return help;
    }

    public void setHelp(HelpEntity help) {
        this.help = help;
    }

    public OnLineEntity getOnLine() {
        return onLine;
    }

    public void setOnLine(OnLineEntity onLine) {
        this.onLine = onLine;
    }

    public static class GeneralEntity {
        private NavBarEntity navBar;
        private String horizontal;
        private String vertical;
        private String horizontalImgUrl;
        private String verticalImgUrl;
        private FrontColorEntity frontColor;
        private String textColor;
        private String highlightColor;
        private String buttonColor;
        private String backButton;
        private double fontSize;

        public double getFontSize() {
            return fontSize;
        }

        public void setFontSize(double fontSize) {
            this.fontSize = fontSize;
        }

        public NavBarEntity getNavBar() {
            return navBar;
        }

        public void setNavBar(NavBarEntity navBar) {
            this.navBar = navBar;
        }

        public String getHorizontal() {
            return horizontal;
        }

        public void setHorizontal(String horizontal) {
            this.horizontal = horizontal;
        }

        public String getVertical() {
            return vertical;
        }

        public void setVertical(String vertical) {
            this.vertical = vertical;
        }

        public String getHorizontalImgUrl() {
            return horizontalImgUrl;
        }

        public void setHorizontalImgUrl(String horizontalImgUrl) {
            this.horizontalImgUrl = horizontalImgUrl;
        }

        public String getVerticalImgUrl() {
            return verticalImgUrl;
        }

        public void setVerticalImgUrl(String verticalImgUrl) {
            this.verticalImgUrl = verticalImgUrl;
        }

        public FrontColorEntity getFrontColor() {
            return frontColor;
        }

        public void setFrontColor(FrontColorEntity frontColor) {
            this.frontColor = frontColor;
        }

        public String getTextColor() {
            return textColor;
        }

        public void setTextColor(String textColor) {
            this.textColor = textColor;
        }

        public String getHighlightColor() {
            return highlightColor;
        }

        public void setHighlightColor(String highlightColor) {
            this.highlightColor = highlightColor;
        }

        public String getButtonColor() {
            return buttonColor;
        }

        public void setButtonColor(String buttonColor) {
            this.buttonColor = buttonColor;
        }

        public String getBackButton() {
            return backButton;
        }

        public void setBackButton(String backButton) {
            this.backButton = backButton;
        }

        public static class NavBarEntity {
            private String color;
            private double transparency;

            public String getColor() {
                return color;
            }

            public void setColor(String color) {
                this.color = color;
            }

            public double getTransparency() {
                return transparency;
            }

            public void setTransparency(double transparency) {
                this.transparency = transparency;
            }
        }

        public static class FrontColorEntity {
            private String color;
            private double transparency;

            public String getColor() {
                return color;
            }

            public void setColor(String color) {
                this.color = color;
            }

            public double getTransparency() {
                return transparency;
            }

            public void setTransparency(double transparency) {
                this.transparency = transparency;
            }
        }
    }

    public static class HelpEntity {
        private String navBar;
        private String noticeBar;
        private String faqList;
        private String faqSectionList;

        public String getNavBar() {
            return navBar;
        }

        public void setNavBar(String navBar) {
            this.navBar = navBar;
        }

        public String getNoticeBar() {
            return noticeBar;
        }

        public void setNoticeBar(String noticeBar) {
            this.noticeBar = noticeBar;
        }

        public String getFaqList() {
            return faqList;
        }

        public void setFaqList(String faqList) {
            this.faqList = faqList;
        }

        public String getFaqSectionList() {
            return faqSectionList;
        }

        public void setFaqSectionList(String faqSectionList) {
            this.faqSectionList = faqSectionList;
        }
    }

    public static class OnLineEntity {
        private String navBar;
        private String robotImgUrl;
        private String customerImgUrl;
        private String userImgUrl;
        private String bgColor;
        private String foreColor;

        public String getNavBar() {
            return navBar;
        }

        public void setNavBar(String navBar) {
            this.navBar = navBar;
        }

        public String getRobotImgUrl() {
            return robotImgUrl;
        }

        public void setRobotImgUrl(String robotImgUrl) {
            this.robotImgUrl = robotImgUrl;
        }

        public String getCustomerImgUrl() {
            return customerImgUrl;
        }

        public void setCustomerImgUrl(String customerImgUrl) {
            this.customerImgUrl = customerImgUrl;
        }

        public String getUserImgUrl() {
            return userImgUrl;
        }

        public void setUserImgUrl(String userImgUrl) {
            this.userImgUrl = userImgUrl;
        }

        public String getBgColor() {
            return bgColor;
        }

        public void setBgColor(String bgColor) {
            this.bgColor = bgColor;
        }

        public String getForeColor() {
            return foreColor;
        }

        public void setForeColor(String foreColor) {
            this.foreColor = foreColor;
        }
    }
}
